==> haskell-hls-gadt-plugin-2.1.0.0-100-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-gadt-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-gadt-plugin
version:              2.1.0.0
visibility:           public
id:                   hls-gadt-plugin-2.1.0.0-4WvCV8caLRy3xkBSv8Lp8j
key:                  hls-gadt-plugin-2.1.0.0-4WvCV8caLRy3xkBSv8Lp8j
license:              Apache-2.0
maintainer:           julytreee@gmail.com
author:               Lei Zhu
synopsis:             Convert to GADT syntax plugin
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server/tree/master/plugins/hls-gadt-plugin#readme>

category:             Development
abi:                  6ee6163159630d522db8221a24d5c347
exposed:              True
exposed-modules:      Ide.Plugin.GADT
hidden-modules:       Ide.Plugin.GHC
import-dirs:          /usr/lib/ghc-9.6.6/site-local/hls-gadt-plugin-2.1.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hls-gadt-plugin-2.1.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hls-gadt-plugin-2.1.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-gadt-plugin
hs-libraries:         HShls-gadt-plugin-2.1.0.0-4WvCV8caLRy3xkBSv8Lp8j
depends:
    aeson-2.1.2.1-GojnAvr1Jep10WUNi5H1Pi base-4.18.2.1 containers-0.6.7
    extra-1.7.16-3o8MjPiNQTlLg74BSenHLy ghc-9.6.6 ghc-boot-th-9.6.6
    ghc-exactprint-1.7.1.0-F0i4FugjRs4FGSGCq308uf
    ghcide-2.1.0.0-FnivsoqaY804ocwiGSGs4S
    hls-plugin-api-2.1.0.0-DLt74c0m6zn5iIl3F9hXDn
    hls-refactor-plugin-2.1.0.0-3a2DGLmo4jC4uYcr4QLr53
    lens-5.3.3-HAYf6JaG0qX5o8D7xn9NgM
    lsp-2.1.0.0-FDkJ3hOfaOyD0G3xXwdyeX mtl-2.3.1 text-2.0.2
    transformers-0.6.1.0
    unordered-containers-0.2.20.1-50qrTxmoJy9AxZ7OdMnycu

haddock-interfaces:
    /usr/share/doc/haskell-hls-gadt-plugin/html/hls-gadt-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-gadt-plugin/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hls-gadt-plugin-2.1.0.0-102-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-gadt-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-gadt-plugin
version:              2.1.0.0
visibility:           public
id:                   hls-gadt-plugin-2.1.0.0-Lycb8Qhq0jlHjJaJlbpmo8
key:                  hls-gadt-plugin-2.1.0.0-Lycb8Qhq0jlHjJaJlbpmo8
license:              Apache-2.0
maintainer:           julytreee@gmail.com
author:               Lei Zhu
synopsis:             Convert to GADT syntax plugin
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server/tree/master/plugins/hls-gadt-plugin#readme>

category:             Development
abi:                  0e2a6b4fcc09583dbf5831eff11a1ca3
exposed:              True
exposed-modules:      Ide.Plugin.GADT
hidden-modules:       Ide.Plugin.GHC
import-dirs:          /usr/lib/ghc-9.6.6/site-local/hls-gadt-plugin-2.1.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hls-gadt-plugin-2.1.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hls-gadt-plugin-2.1.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-gadt-plugin
hs-libraries:         HShls-gadt-plugin-2.1.0.0-Lycb8Qhq0jlHjJaJlbpmo8
depends:
    aeson-2.1.2.1-CpIoOLI7lIpJkSqSOmDN9y base-4.18.2.1 containers-0.6.7
    extra-1.7.16-IkudFHstV64EKMSGT8IWWb ghc-9.6.6 ghc-boot-th-9.6.6
    ghc-exactprint-1.7.1.0-Icc6yarV61YJwCVVP7qqo9
    ghcide-2.1.0.0-FpGXYcNEFHuE24CSyfyNdp
    hls-plugin-api-2.1.0.0-BfiKLSupfw45UdhJj6iHuY
    hls-refactor-plugin-2.1.0.0-IMWSL03tp3QLVnlPUttUmn
    lens-5.3.3-GI3kNGpcyiIBMdla72MFoB lsp-2.1.0.0-jiZ0SP1Jku9ft66mbKdaK
    mtl-2.3.1 text-2.0.2 transformers-0.6.1.0
    unordered-containers-0.2.20.1-L0jiELAFLwP1g4FZscm3B5

haddock-interfaces:
    /usr/share/doc/haskell-hls-gadt-plugin/html/hls-gadt-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-gadt-plugin/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
